#include "bs.h"

/**
 * Return an index of val in vals.  If val does not
 * appear in vals, returns -1.
 *
 * @pre: Vals is sorted in non-decreasing order.
 */
int
binary_search (int val, int vals[], int n)
{
  return -1;    // STUB
} // binary_search

