#ifndef _BS_H_
#define _BS_H_

/**
 * Return an index of val in vals.  If val does not
 * appear in vals, returns -1.
 *
 * @pre: Vals is sorted in non-decreasing order.
 */
int binary_search (int val, int vals[], int n);

#endif // _BS_H_
